@@ -26,7 +26,8 @@
 #define _CXP_H
 
 #include <cxp-profile.h>
+#include <cxp-handler.h>
 #include <cxp-utils.h>
-#include <cxp-gui.h>
+#include <cxp-entry-dialog.h>
 
 #endif /* _CXP_H */
